"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const act_1 = __importDefault(require("./act"));
const errors_1 = require("./helpers/errors");
const findEventHandler = (element, eventName, callsite) => {
    const eventHandler = toEventHandlerName(eventName);
    if (typeof element.props[eventHandler] === 'function') {
        return element.props[eventHandler];
    }
    else if (typeof element.props[eventName] === 'function') {
        return element.props[eventName];
    }
    else if (element.props.on &&
        typeof element.props.on[eventName] === 'function') {
        return element.props.on[eventName];
    }
    // Do not bubble event to the root element
    if (element.parent === null || element.parent.parent === null) {
        throw new errors_1.ErrorWithStack(`No handler function found for event: "${eventName}"`, callsite || invokeEvent);
    }
    return findEventHandler(element.parent, eventName, callsite);
};
const invokeEvent = (element, eventName, callsite, ...data) => {
    const handler = findEventHandler(element, eventName, callsite);
    if (!handler) {
        return null;
    }
    let returnValue;
    act_1.default(() => {
        returnValue = handler(...data);
    });
    return returnValue;
};
const toEventHandlerName = (eventName) => `on${eventName.charAt(0).toUpperCase()}${eventName.slice(1)}`;
const clickHandler = (element) => invokeEvent(element, 'clicked', clickHandler);
const changeTextHandler = (element, ...data) => invokeEvent(element, 'textChanged', changeTextHandler, ...data);
const fireEvent = (element, eventName, ...data) => invokeEvent(element, eventName, fireEvent, ...data);
fireEvent.click = clickHandler;
fireEvent.changeText = changeTextHandler;
exports.default = fireEvent;
//# sourceMappingURL=fireEvent.js.map