"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_1 = require("./errors");
function isNodeValid(node) {
    return typeof node.type === 'string';
}
function makeAliases(aliases, query) {
    return aliases
        .map(alias => ({ [alias]: query }))
        .reduce((acc, query) => (Object.assign(Object.assign({}, acc), query)), {});
}
const makeQuery = (name, queryNames, matcherFn) => (instance) => {
    const getBy = (matcher) => {
        try {
            return instance.find(node => isNodeValid(node) && matcherFn(node.props[name], matcher));
        }
        catch (error) {
            throw new errors_1.ErrorWithStack(errors_1.prepareErrorMessage(error), getBy);
        }
    };
    const getAllBy = (matcher) => {
        const results = instance.findAll(node => isNodeValid(node) && matcherFn(node.props[name], matcher));
        if (results.length === 0) {
            throw new errors_1.ErrorWithStack('No instances found', getAllBy);
        }
        return results;
    };
    const queryBy = (matcher) => {
        try {
            return getBy(matcher);
        }
        catch (error) {
            return errors_1.createQueryByError(error, queryBy);
        }
    };
    const queryAllBy = (matcher) => {
        try {
            return getAllBy(matcher);
        }
        catch (error) {
            return [];
        }
    };
    return Object.assign(Object.assign(Object.assign(Object.assign({}, makeAliases(queryNames.getBy, getBy)), makeAliases(queryNames.getAllBy, getAllBy)), makeAliases(queryNames.queryBy, queryBy)), makeAliases(queryNames.queryAllBy, queryAllBy));
};
exports.default = makeQuery;
//# sourceMappingURL=makeQuery.js.map