"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const getByAPI_1 = require("./getByAPI");
const errors_1 = require("./errors");
exports.queryByType = (instance) => function queryByTypeFn(type) {
    try {
        return getByAPI_1.getByType(instance)(type);
    }
    catch (error) {
        return errors_1.createQueryByError(error, queryByTypeFn);
    }
};
exports.queryByText = (instance) => function queryByTextFn(text) {
    try {
        return getByAPI_1.getByText(instance)(text);
    }
    catch (error) {
        return errors_1.createQueryByError(error, queryByTextFn);
    }
};
exports.queryByPlaceholder = (instance) => function queryByPlaceholderFn(placeholder) {
    try {
        return getByAPI_1.getByPlaceholder(instance)(placeholder);
    }
    catch (error) {
        return errors_1.createQueryByError(error, queryByPlaceholderFn);
    }
};
exports.queryByDisplayValue = (instance) => function queryByDisplayValueFn(value) {
    try {
        return getByAPI_1.getByDisplayValue(instance)(value);
    }
    catch (error) {
        return errors_1.createQueryByError(error, queryByDisplayValueFn);
    }
};
exports.queryByProps = (instance) => function queryByPropsFn(props) {
    try {
        return getByAPI_1.getByProps(instance)(props);
    }
    catch (error) {
        return errors_1.createQueryByError(error, queryByPropsFn);
    }
};
exports.queryByTestId = (instance) => function queryByTestIdFn(testID) {
    try {
        return getByAPI_1.getByTestId(instance)(testID);
    }
    catch (error) {
        return errors_1.createQueryByError(error, queryByTestIdFn);
    }
};
exports.queryAllByType = (instance) => (type) => {
    try {
        return getByAPI_1.getAllByType(instance)(type);
    }
    catch (error) {
        return [];
    }
};
exports.queryAllByText = (instance) => (text) => {
    try {
        return getByAPI_1.getAllByText(instance)(text);
    }
    catch (error) {
        return [];
    }
};
exports.queryAllByPlaceholder = (instance) => (placeholder) => {
    try {
        return getByAPI_1.getAllByPlaceholder(instance)(placeholder);
    }
    catch (error) {
        return [];
    }
};
exports.queryAllByDisplayValue = (instance) => (value) => {
    try {
        return getByAPI_1.getAllByDisplayValue(instance)(value);
    }
    catch (error) {
        return [];
    }
};
exports.queryAllByProps = (instance) => (props) => {
    try {
        return getByAPI_1.getAllByProps(instance)(props);
    }
    catch (error) {
        return [];
    }
};
exports.queryAllByTestId = (instance) => (testID) => {
    try {
        return getByAPI_1.getAllByTestId(instance)(testID);
    }
    catch (error) {
        return [];
    }
};
exports.queryByAPI = (instance) => ({
    queryByTestId: exports.queryByTestId(instance),
    queryByType: exports.queryByType(instance),
    queryByText: exports.queryByText(instance),
    queryByPlaceholder: exports.queryByPlaceholder(instance),
    queryByDisplayValue: exports.queryByDisplayValue(instance),
    queryByProps: exports.queryByProps(instance),
    queryAllByTestId: exports.queryAllByTestId(instance),
    queryAllByType: exports.queryAllByType(instance),
    queryAllByText: exports.queryAllByText(instance),
    queryAllByPlaceholder: exports.queryAllByPlaceholder(instance),
    queryAllByDisplayValue: exports.queryAllByDisplayValue(instance),
    queryAllByProps: exports.queryAllByProps(instance),
});
//# sourceMappingURL=queryByAPI.js.map