"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_test_renderer_1 = __importDefault(require("react-test-renderer"));
const act_1 = __importDefault(require("./act"));
const cleanup_1 = require("./cleanup");
const getByAPI_1 = require("./helpers/getByAPI");
const queryByAPI_1 = require("./helpers/queryByAPI");
const debugShallow_1 = __importDefault(require("./helpers/debugShallow"));
const debugDeep_1 = __importDefault(require("./helpers/debugDeep"));
// eslint-disable-next-line @typescript-eslint/explicit-function-return-type
function render(component, { wrapper: Wrapper, createNodeMock } = {}) {
    const wrap = (innerElement) => Wrapper ? react_1.default.createElement(Wrapper, null, innerElement) : innerElement;
    const renderer = renderWithAct(wrap(component), createNodeMock ? { createNodeMock } : undefined);
    const update = updateWithAct(renderer, wrap);
    const instance = renderer.root;
    cleanup_1.addToCleanupQueue(renderer.unmount);
    return Object.assign(Object.assign(Object.assign({}, getByAPI_1.getByAPI(instance)), queryByAPI_1.queryByAPI(instance)), { update, rerender: update, unmount: renderer.unmount, toJSON: renderer.toJSON, debug: debug(instance, renderer) });
}
exports.default = render;
function renderWithAct(component, options) {
    let renderer;
    act_1.default(() => {
        renderer = react_test_renderer_1.default.create(component, options);
    });
    return renderer;
}
function updateWithAct(renderer, wrap) {
    return function (component) {
        act_1.default(() => {
            renderer.update(wrap(component));
        });
    };
}
function debug(instance, renderer) {
    const debugImpl = message => {
        return debugDeep_1.default(renderer.toJSON(), message);
    };
    debugImpl.shallow = message => debugShallow_1.default(instance, message);
    return debugImpl;
}
//# sourceMappingURL=render.js.map